// Copyright 2010-2020, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#include "rewriter/collocation_util.h"

#include "testing/base/public/gunit.h"

namespace mozc {
namespace {

TEST(CollocationUtilTest, GetNormalizedScript) {
  std::string result;
  CollocationUtil::GetNormalizedScript("あいうえお", true, &result);
  EXPECT_EQ("あいうえお", result);

  CollocationUtil::GetNormalizedScript("あいうえお", false, &result);
  EXPECT_EQ("あいうえお", result);

  CollocationUtil::GetNormalizedScript("1個", true, &result);
  EXPECT_EQ("個", result);
  CollocationUtil::GetNormalizedScript("1個", false, &result);
  EXPECT_EQ("1個", result);

  CollocationUtil::GetNormalizedScript("１個", true, &result);
  EXPECT_EQ("個", result);
  CollocationUtil::GetNormalizedScript("１個", false, &result);
  EXPECT_EQ("１個", result);

  CollocationUtil::GetNormalizedScript("", true, &result);
  EXPECT_EQ("", result);
  CollocationUtil::GetNormalizedScript("", false, &result);
  EXPECT_EQ("", result);

  CollocationUtil::GetNormalizedScript("＄", true, &result);
  EXPECT_EQ("", result);
  CollocationUtil::GetNormalizedScript("＄", false, &result);
  EXPECT_EQ("", result);

  CollocationUtil::GetNormalizedScript("等々", true, &result);
  EXPECT_EQ("等々", result);
  CollocationUtil::GetNormalizedScript("等々", false, &result);
  EXPECT_EQ("等々", result);

  CollocationUtil::GetNormalizedScript("％%％", true, &result);
  EXPECT_EQ("%%%", result);
  CollocationUtil::GetNormalizedScript("％%％", false, &result);
  EXPECT_EQ("%%%", result);
}

}  // namespace
}  // namespace mozc
